@@ -228,7 +228,7 @@ class Graph:
     def __init__(self, name: t.Optional[str] = None):
         """Create a graph from scratch."""
 
-        self.name = name or ""
+        self.name = name or utils.unique_id()
         self._nodes = ImmutableDict()
         self._atom_nodes = ImmutableDict()
         self._scheme_nodes = ImmutableDict()
@@ -293,6 +293,13 @@ class Graph:
             if node.participant and node.participant.id not in self._participants:
                 self.add_participant(node.participant)
 
+            if (
+                node.reference
+                and node.reference.resource
+                and node.reference.resource.id not in self._resources
+            ):
+                self.add_resource(node.reference.resource)
+
         elif isinstance(node, SchemeNode):
             self._scheme_nodes._store[node.id] = node
 
@@ -476,9 +483,22 @@ class Graph:
 
         for node in self._atom_nodes.values():
             if node.reference and node.reference.resource == resource:
-                node.reference.resource = None
+                node.reference._resource = None
                 node.reference.offset = None
 
+    def clean_resources(self) -> None:
+        """Remove resources from the graph that are used by no nodes"""
+
+        node_resources = {
+            node.reference.resource.id
+            for node in self._atom_nodes.values()
+            if node.reference and node.reference.resource
+        }
+
+        for resource_id in set(self._resources):
+            if resource_id not in node_resources:
+                del self._resources._store[resource_id]
+
     def add_participant(self, participant: Participant) -> None:
         """Add a resource.
 
@@ -528,7 +548,20 @@ class Graph:
 
         for node in self._atom_nodes.values():
             if node.participant == participant:
-                node.participant = None
+                node._participant = None
+
+    def clean_participants(self) -> None:
+        """Remove resources from the graph that are used by no nodes"""
+
+        node_participants = {
+            node.participant.id
+            for node in self._atom_nodes.values()
+            if node.participant
+        }
+
+        for participant in set(self._participants):
+            if participant not in node_participants:
+                del self._participants._store[participant]
 
     def node_distance(
         self,
@@ -646,7 +679,7 @@ class Graph:
                     # The id is prefixed with 'node', e.g. 'node5'.
                     node_key = elem.attrib["id"].replace("node", "")
                     if node := g._atom_nodes.get(node_key):
-                        node.reference = Reference(
+                        node._reference = Reference(
                             resource, len(text), utils.parse(elem.text, nlp)
                         )
 
@@ -886,7 +919,7 @@ class Graph:
 
             if row[0].startswith("T"):
                 if metadata[0] == "MajorClaim":
-                    mc.text = utils.parse(mc.plain_text + ". " + row[2], nlp)
+                    mc.text = utils.parse(f"{mc.plain_text}. {row[2]}", nlp)
                 else:
                     atom = atom_class(utils.parse(row[2], nlp))
                     g.add_node(atom)
@@ -1080,17 +1113,17 @@ class Graph:
         suffixes: t.Iterable[str] = (".json"),
     ) -> t.List[Graph]:
         "Generate Graph structure from Folder."
-        graphs = []
+        return [
+            cls.from_file(file, atom_class, scheme_class, edge_class, nlp)
+            for suffix in suffixes
+            for file in sorted(path.rglob(f"*{suffix}"))
+        ]
 
-        for suffix in suffixes:
-            for file in sorted(path.rglob(f"*{suffix}")):
-                graphs.append(
-                    cls.from_file(file, atom_class, scheme_class, edge_class, nlp)
-                )
-
-        return graphs
-
-    def to_nx(self) -> nx.DiGraph:
+    def to_nx(
+        self,
+        atom_label: t.Optional[t.Callable[[AtomNode], str]] = None,
+        scheme_label: t.Optional[t.Callable[[SchemeNode], str]] = None,
+    ) -> nx.DiGraph:
         """Transform a Graph instance into an instance of networkx directed graph. Refer to the networkx library for additional information.
 
         Examples:
@@ -1107,8 +1140,11 @@ class Graph:
         """
         g = nx.DiGraph()
 
-        for node in self._nodes.values():
-            node.to_nx(g)
+        for node in self._atom_nodes.values():
+            node.to_nx(g, atom_label)
+
+        for node in self._scheme_nodes.values():
+            node.to_nx(g, scheme_label)
 
         for edge in self._edges.values():
             edge.to_nx(g)
@@ -1125,6 +1161,8 @@ class Graph:
         margin: t.Optional[t.Tuple[float, float]] = None,
         font_name: t.Optional[str] = None,
         font_size: t.Optional[float] = None,
+        atom_label: t.Optional[t.Callable[[AtomNode], str]] = None,
+        scheme_label: t.Optional[t.Callable[[SchemeNode], str]] = None,
         graph_attr: t.Optional[t.Mapping[str, str]] = None,
         node_attr: t.Optional[t.Mapping[str, str]] = None,
         edge_attr: t.Optional[t.Mapping[str, str]] = None,
@@ -1166,10 +1204,19 @@ class Graph:
             },
         )
 
-        for node in self._nodes.values():
+        for node in self._atom_nodes.values():
             node.to_gv(
                 g,
                 self.major_claim == node,
+                label_func=atom_label,
+                wrap_col=wrap_col or 36,
+            )
+
+        for node in self._scheme_nodes.values():
+            node.to_gv(
+                g,
+                self.major_claim == node,
+                label_func=scheme_label,
                 wrap_col=wrap_col or 36,
             )
 
