@@ -449,7 +449,7 @@ class Node(ABC):
         pass
 
     @abstractmethod
-    def to_nx(self, g: nx.DiGraph) -> None:
+    def to_nx(self, g: nx.DiGraph, label_attr: t.Optional[str] = None) -> None:
         """Submethod used to export Graph object g into NX Graph format."""
         pass
 
@@ -521,13 +521,13 @@ class AtomNode(Node):
         "updated",
         "metadata",
         "text",
-        "reference",
-        "participant",
+        "_reference",
+        "_participant",
     )
 
     text: t.Any
-    reference: t.Optional[Reference]
-    participant: t.Optional[Participant]
+    _reference: t.Optional[Reference]
+    _participant: t.Optional[Participant]
 
     def __init__(
         self,
@@ -541,8 +541,8 @@ class AtomNode(Node):
     ):
         super().__init__(created, updated, metadata, id)
         self.text = text
-        self.reference = resource
-        self.participant = participant
+        self._reference = resource
+        self._participant = participant
 
     @property
     def plain_text(self) -> str:
@@ -550,6 +550,14 @@ class AtomNode(Node):
 
         return utils.xstr(self.text)
 
+    @property
+    def reference(self) -> t.Optional[Reference]:
+        return self._reference
+
+    @property
+    def participant(self) -> t.Optional[Participant]:
+        return self._participant
+
     def __repr__(self):
         return utils.class_repr(self, [self._id, self.plain_text])
 
@@ -624,11 +632,13 @@ class AtomNode(Node):
 
         return obj
 
-    def to_nx(self, g: nx.DiGraph) -> None:
+    def to_nx(
+        self, g: nx.DiGraph, label_func: t.Optional[t.Callable[[AtomNode], str]] = None
+    ) -> None:
         """Submethod used to export Graph object g into NX Graph format."""
         g.add_node(
             self._id,
-            label=self.plain_text,
+            label=label_func(self) if label_func else self.plain_text,
         )
 
     def color(self, major_claim: bool) -> ColorMapping:
@@ -638,15 +648,22 @@ class AtomNode(Node):
 
         return ColorMapping(bg="#ddeef9", border="#3498db")
 
-    def to_gv(self, g: gv.Digraph, major_claim: bool, wrap_col: int) -> None:
+    def to_gv(
+        self,
+        g: gv.Digraph,
+        major_claim: bool,
+        wrap_col: int,
+        label_func: t.Optional[t.Callable[[AtomNode], str]] = None,
+    ) -> None:
         """Submethod used to export Graph object g into GV Graph format."""
         color = self.color(major_claim)
+        label = label_func(self) if label_func else self.plain_text
 
         # TODO: Improve wrapping
         # https://stackoverflow.com/a/26538082/7626878
         g.node(
             self._id,
-            label=textwrap.fill(self.plain_text, wrap_col).strip(),
+            label=textwrap.fill(label, wrap_col).strip(),
             fontcolor=color.fg,
             fillcolor=color.bg,
             color=color.border,
@@ -811,13 +828,22 @@ class SchemeNode(Node):
 
         return obj
 
-    def to_nx(self, g: nx.DiGraph) -> None:
+    def to_nx(
+        self,
+        g: nx.DiGraph,
+        label_func: t.Optional[t.Callable[[SchemeNode], str]] = None,
+    ) -> None:
         """Submethod used to export Graph object g into NX Graph format."""
+        if label_func:
+            label = label_func(self)
+        elif self.argumentation_scheme:
+            label = f"{scheme_type2text[self.type]}: {scheme2text[self.argumentation_scheme]}"
+        else:
+            label = scheme_type2text[self.type]
+
         g.add_node(
             self._id,
-            label=scheme2text[self.argumentation_scheme]
-            if self.argumentation_scheme
-            else scheme_type2text[self.type],
+            label=label,
         )
 
     def color(self, major_claim: bool) -> ColorMapping:
@@ -837,10 +863,23 @@ class SchemeNode(Node):
 
         return ColorMapping(bg="#e9eded", border="#95a5a6")
 
-    def to_gv(self, g: gv.Digraph, major_claim: bool, wrap_col: int) -> None:
+    def to_gv(
+        self,
+        g: gv.Digraph,
+        major_claim: bool,
+        wrap_col: int,
+        label_func: t.Optional[t.Callable[[SchemeNode], str]] = None,
+    ) -> None:
         """Submethod used to export Graph object g into GV Graph format."""
         color = self.color(major_claim)
 
+        if label_func:
+            label = label_func(self)
+        elif self.argumentation_scheme:
+            label = f"{scheme_type2text[self.type]}: {scheme2text[self.argumentation_scheme]}"
+        else:
+            label = scheme_type2text[self.type]
+
         g.node(
             self._id,
             label=scheme2text[self.argumentation_scheme]
